<img src="figs/LANCET_EUROPE_LOGO.png" alt="drawing" width="270"/>  

<div align="justify">

This project is licensed under GNU General Public License version 3 ([GPL-3](https://www.gnu.org/licenses/gpl-3.0))

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)    

# Indicator 1.3.6: Climatic Suitability for Ticks

## Introduction

Tick-borne diseases (TBDs) are the most common vector-borne diseases in the Northern Hemisphere. **Lyme disease (LD)** is the most frequent TBD in Europe, with over 200,000 cases reported per year in Western Europe alone. The second most prevalent TBD is **tick-borne encephailitis (TBE)**, caused by virus of the *Flaviviridae* family, also known as the TBE-virus. There is evidence of the spread of tick species of public health relevance towards higher altitudes and latitudes in the Northern Hemisphere. Although there is a wide consensus  about the growing risk that TBDs pose to the vulnerable populations, there is the need to track changes in the length of the questing season over the last decades.

This indicator produces annual grid products of the length of the seasons (i.e. number of months per year) suitable for *I. ricinus* to engage in questing at a resolution of ~9 km. Additionally, it is possible to average results to administrative regions, such as NUTS3 and country. These outputs will indicate new areas of high exposure, as well as serve as tools to advise policy-makers of where and when to target prevention strategies.

## Methods

This indicator is derived from a threshold-based model. Suitability for a particular month is defined as the coincidence of average temperature between 10°C and 26°C, and relative humidity greater than 45% ([Nolzen et al., 2022](https://doi.org/10.1371/journal.pone.0267196)), and land classes where *I. ricinus* was reported ([GBIF](https://www.gbif.org/es/)).

#### Data sources

<div align="left">

| Variable | Source | Spatial Resolution | Temporal range used | 
| ------ | ------ | ------ | ------ |
| Monthly 2 meter dew point temperature | [ERA5-Land (monthly)](https://cds.climate.copernicus.eu/cdsapp#!/dataset/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1951 - Dec 2022 |
| Monthly 2 meter temperature | [ERA5-Land (monthly)](https://cds.climate.copernicus.eu/cdsapp#!/dataset/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1951 - Dec 2022 |
| Land cover | [CORINE](https://land.copernicus.eu/pan-european/corine-land-cover/clc2018) | 100m | 2018 |
| *Ixodes ricinus* presence | [GBIF](https://www.gbif.org/es/) | Point data | 2012 - 2018 |

<div align="justify">

## Content
This repository contains final products and scripts, organized as follows. Intermediate products are available upon request.

* **01_compute_climate_suitability.sh** 
    * Import and transform climate variables
    * Compute relative humidity
    * Compute and save climate suitability

* **02_explore_land_classes.R**
    * Locate land cover classes with more frequent reports of *Ixodes ricinus*

* **03_compute_environmental_weigths.R**
    * Compute proportion of suitable land cover classes per climate grid cell

* **04_ixodes_environmental_suitability.R**
    * Create map of environmental suitability

* **05_ixodes_suitability.R**
    * Compute malaria suitability per adminsitrative until

* **06_ixodes_timelines.R**
    * Create timeline figures

## Authors

##### - Martín Lotto Batista, MSc [(Web)](https://www.bsc.es/lotto-batista-martin)
##### - Prof. Rachel Lowe [(Web)](https://www.bsc.es/lowe-rachel)

##### Contact: martin.lotto@bsc.es
